import { DecoratorAttributeConfiguration } from "@microsoft/fast-element";
import { DesignSystemProvider } from "./design-system-provider";
/**
 * Configuration object for defining a {@link @microsoft/fast-foundation#DesignSystemProvider} property
 *
 * @public
 */
export interface DecoratorDesignSystemPropertyConfiguration extends Omit<DecoratorAttributeConfiguration, "attribute"> {
    /**
     * The HTML attribute name to map the property to - defaults to the property name.
     */
    attribute?: string | false;
    /**
     * An optional property to control the name of the css custom property being created.
     * If omitted, the css custom property will share a name with attribute if specified, otherwise the property name being decorated.
     * If assigned a false value, no css custom property will be created.
     */
    cssCustomProperty?: string | false;
    /**
     * The default value of the property. Will be assigned when the use-defaults attribute is used.
     */
    default: any;
}
/**
 * Decorator to declare a property as a design-system property.
 * Intended to be used with the {@link @microsoft/fast-foundation#DesignSystemProvider}
 * @param config - {@link DecoratorDesignSystemPropertyConfiguration}
 *
 * @public
 */
export declare function designSystemProperty<T extends DesignSystemProvider>(config: DecoratorDesignSystemPropertyConfiguration): (source: T, property: string) => void;
