import { children, elements, html, slotted } from "@microsoft/fast-element";
function createCellItemTemplate(prefix) {
    return html `
    <${prefix}-data-grid-cell
        grid-column="${(x, c) => c.index + 1}"
        :rowData="${(x, c) => c.parent.rowData}"
        :columnDefinition="${x => x}"
    ></${prefix}-data-grid-cell>
`;
}
function createHeaderCellItemTemplate(prefix) {
    return html `
    <${prefix}-data-grid-cell
        cell-type="columnheader"
        grid-column="${(x, c) => c.index + 1}"
        :columnDefinition="${x => x}"
    ></${prefix}-data-grid-header-cell>
`;
}
/**
 * Generates a template for the {@link @microsoft/fast-foundation#DataGridRow} component using
 * the provided prefix.
 *
 * @public
 */
export function createDataGridRowTemplate(prefix) {
    const cellItemTemplate = createCellItemTemplate(prefix);
    const headerCellItemTemplate = createHeaderCellItemTemplate(prefix);
    return html `
        <template
            role="row"
            class="${x => (x.rowType !== "default" ? x.rowType : "")}"
            :defaultCellItemTemplate="${cellItemTemplate}"
            :defaultHeaderCellItemTemplate="${headerCellItemTemplate}"
            ${children({
        property: "cellElements",
        filter: elements('[role="cell"],[role="gridcell"],[role="columnheader"]'),
    })}
        >
            <slot ${slotted("slottedCellElements")}></slot>
        </template>
    `;
}
