import { __awaiter } from "tslib";
import { defaultExecutionContext, ViewTemplate, } from "@microsoft/fast-element";
function findElement(view) {
    let current = view.firstChild;
    while (current !== null && current.nodeType !== 1) {
        current = current.nextSibling;
    }
    return current;
}
/**
 * Creates a random, unique name suitable for use as a Custom Element name.
 */
export function uniqueElementName() {
    return `fast-unique-${Math.random().toString(36).substring(7)}`;
}
/**
 * Creates a test fixture suitable for testing custom elements, templates, and bindings.
 * @param templateOrElementName An HTML template or single element name to create the fixture for.
 * @param options Enables customizing fixture creation behavior.
 * @remarks
 * Yields control to the caller one Microtask later, in order to
 * ensure that the DOM has settled.
 */
export function fixture(templateOrElementName, options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        if (typeof templateOrElementName === "string") {
            const html = `<${templateOrElementName}></${templateOrElementName}>`;
            templateOrElementName = new ViewTemplate(html, []);
        }
        const view = templateOrElementName.create();
        const document = options.document || globalThis.document;
        const parent = options.parent || document.createElement("div");
        const source = options.source || {};
        const context = options.context || defaultExecutionContext;
        const element = findElement(view);
        let isConnected = false;
        view.bind(source, context);
        view.appendTo(parent);
        customElements.upgrade(parent);
        // Hook into the Microtask Queue to ensure the DOM is settled
        // before yielding control to the caller.
        yield Promise.resolve();
        const connect = () => __awaiter(this, void 0, void 0, function* () {
            if (isConnected) {
                return;
            }
            isConnected = true;
            document.body.appendChild(parent);
            yield Promise.resolve();
        });
        const disconnect = () => __awaiter(this, void 0, void 0, function* () {
            if (!isConnected) {
                return;
            }
            isConnected = false;
            document.body.removeChild(parent);
            yield Promise.resolve();
        });
        return {
            document,
            template: templateOrElementName,
            view,
            parent,
            element,
            connect,
            disconnect,
        };
    });
}
